#### Description
Java code commit impact analysis, is a pure python library that analyzes the impact of two git submissions of Java projects on the project and generates tree chart data.

Github: [jcci](https://github.com/baikaishuipp/jcci)
#### Installation
```
pip install jcci
```

#### Instructions
Start a new python project, add a new python file, code example:

```
from jcci import jcci

# Compare different commits on the same branch
jcci.analyze('git@xxxx.git','master','commit_id1','commit_id2', 'username1')

```

At the same time, the project will be cloned in the directory and then analyzed to generate a file with the suffix format commit_id1...commit_id2.cci, which contains the tree diagram data generated by the analysis results, download [jcci-result.html](https://github.com/baikaishuipp/jcci/blob/main/jcci-result.html) , upload analyze result file end with .cci, then can be displayed through the view.

##### CCI result
![result](https://raw.githubusercontent.com/baikaishuipp/jcci/main/images/cci-result.png)

##### CCI result tree view
![treeView](https://raw.githubusercontent.com/baikaishuipp/jcci/main/images/cii-result-tree.png)
